.. _modules_abstract_common:

Abstract Common Model
=====================
This is the common model class

.. module:: pyorbit.common.abstract_common

Some stuff here

.. automodule:: pyorbit.common.abstract_common
   :members:
